"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadSelectedTheme = exports.useSelectedTheme = void 0;
var nativewind_1 = require("nativewind");
var react_1 = __importDefault(require("react"));
var react_native_mmkv_1 = require("react-native-mmkv");
var storage_1 = require("../storage");
var SELECTED_THEME = 'SELECTED_THEME';
/**
 * this hooks should only be used while selecting the theme
 * This hooks will return the selected theme which is stored in MMKV
 * selectedTheme should be one of the following values 'light', 'dark' or 'system'
 * don't use this hooks if you want to use it to style your component based on the theme use useColorScheme from nativewind instead
 *
 */
var useSelectedTheme = function () {
    var _a = (0, nativewind_1.useColorScheme)(), _color = _a.colorScheme, setColorScheme = _a.setColorScheme;
    var _b = (0, react_native_mmkv_1.useMMKVString)(SELECTED_THEME, storage_1.storage), theme = _b[0], _setTheme = _b[1];
    var setSelectedTheme = react_1.default.useCallback(function (t) {
        setColorScheme(t);
        _setTheme(t);
    }, [setColorScheme, _setTheme]);
    var selectedTheme = (theme !== null && theme !== void 0 ? theme : 'system');
    return { selectedTheme: selectedTheme, setSelectedTheme: setSelectedTheme };
};
exports.useSelectedTheme = useSelectedTheme;
// to be used in the root file to load the selected theme from MMKV
var loadSelectedTheme = function () {
    var theme = storage_1.storage.getString(SELECTED_THEME);
    if (theme !== undefined) {
        console.log('theme', theme);
        nativewind_1.colorScheme.set(theme);
    }
};
exports.loadSelectedTheme = loadSelectedTheme;
//# sourceMappingURL=use-selected-theme.js.map